@@ -96,10 +96,10 @@ plotres(gpe.mod, which=3, info=TRUE, main="gpe.mod residuals")
 # multinomial response
 
 set.seed(2018)
-pre.iris <- pre(Species~., data=iris, ntrees=10) # ntrees=10 for faster test
+pre.iris <- pre(Species~., data=iris, ntrees=10) # ntrees=10 for faster testoptions(warn=2) # treat warnings as errors
 options(warn=2) # treat warnings as errors
-expect.err(try(plotmo(pre.iris)), "predict.pre returned multiple columns (see above) but nresponse is not specified")
+expect.err(try(plotmo(pre.iris)), "Defaulting to nresponse=1, see above messages")
 options(warn=1) # print warnings as they occur
-plotmo(pre.iris, all2=TRUE, nresponse="virginica")
+plotmo(pre.iris, all2=TRUE, nresponse="virginica", trace=1)
 
 source("test.epilog.R")
